==> spring-cloud-commons-1.2.5.RELEASE-sources.jar: org/springframework/cloud/client/hypermedia/DynamicServiceInstanceProvider.java <==
/*
 * Copyright 2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.cloud.client.hypermedia;

import lombok.RequiredArgsConstructor;

import java.util.List;

import org.springframework.cloud.client.ServiceInstance;
import org.springframework.cloud.client.discovery.DiscoveryClient;

/**
 * {@link ServiceInstanceProvider} to work with a {@link DiscoveryClient} to lookup a service by name. Will pick the
 * first one returned by the configured {@link DiscoveryClient}.
 * 
 * @author Oliver Gierke
 */
@RequiredArgsConstructor
public class DynamicServiceInstanceProvider implements ServiceInstanceProvider {

	private final DiscoveryClient client;
	private final String serviceName;

	/* 
	 * (non-Javadoc)
	 * @see example.customers.integration.ServiceInstanceProvider#getServiceInstance()
	 */
	@Override
	public ServiceInstance getServiceInstance() {

		try {

			List<ServiceInstance> instances = client.getInstances(serviceName);
			return instances.isEmpty() ? null : instances.get(0);

		} catch (RuntimeException o_O) {
			return null;
		}
	}
}

==> spring-cloud-commons-2.0.4.RELEASE-sources.jar: org/springframework/cloud/client/hypermedia/DynamicServiceInstanceProvider.java <==
/*
 * Copyright 2015-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.cloud.client.hypermedia;

import java.util.List;

import org.springframework.cloud.client.ServiceInstance;
import org.springframework.cloud.client.discovery.DiscoveryClient;

/**
 * {@link ServiceInstanceProvider} to work with a {@link DiscoveryClient} to lookup a service by name. Will pick the
 * first one returned by the configured {@link DiscoveryClient}.
 * 
 * @author Oliver Gierke
 */
public class DynamicServiceInstanceProvider implements ServiceInstanceProvider {

	private final DiscoveryClient client;
	private final String serviceName;

	public DynamicServiceInstanceProvider(DiscoveryClient client, String serviceName) {
		this.client = client;
		this.serviceName = serviceName;
	}

	/* 
		 * (non-Javadoc)
		 * @see example.customers.integration.ServiceInstanceProvider#getServiceInstance()
		 */
	@Override
	public ServiceInstance getServiceInstance() {

		try {

			List<ServiceInstance> instances = client.getInstances(serviceName);
			return instances.isEmpty() ? null : instances.get(0);

		} catch (RuntimeException o_O) {
			return null;
		}
	}
}
